@@ -1,38 +1,28 @@
 package List::Util::MaybeXS;
 use strict;
 use warnings;
+
 use Exporter (); BEGIN { *import = \&Exporter::import }
 
-our $VERSION = '1.500_007';
+our $VERSION = '1.50';
 $VERSION =~ tr/_//d;
 
 our @EXPORT_OK;
 BEGIN {
   @EXPORT_OK = qw(
-    all any first none notall
-    min max minstr maxstr
-    product reductions reduce sum sum0
-    sample shuffle
-    uniq uniqnum uniqint uniqstr
+    all any first min max minstr maxstr none notall
+    product reduce sum sum0
+    shuffle uniq uniqnum uniqstr
     pairs unpairs pairkeys pairvalues pairmap pairgrep pairfirst
     head tail
-    zip zip_longest zip_shortest
-    mesh mesh_longest mesh_shortest
   );
 }
 
-my $rand = do { our $RAND };
-*RAND                 = *List::Util::RAND;
-*List::Util::PP::RAND = *List::Util::RAND;
-our $RAND;
-$RAND = $rand
-  if !defined $RAND;
-
 BEGIN {
   my %need;
   @need{@EXPORT_OK} = ();
   local $@;
-  if (eval { require List::Util; 1 }) {
+  if (!$ENV{PERL_LIST_UTIL_MAYBEXS_NO_XS} && eval { require List::Util; 1 }) {
     my @import = grep defined &{"List::Util::$_"}, keys %need;
     if ( ! eval { List::Util->VERSION(1.45) } ) {
       @import = grep !/^uniq/, @import;
@@ -56,13 +46,7 @@ List::Util::MaybeXS - L<List::Util> but with Pure Perl fallback
 =head1 SYNOPSIS
 
   use List::Util::MaybeXS qw(
-    reduce any all none notall first reductions
-
-    max maxstr min minstr product sum sum0
-
-    pairs unpairs pairkeys pairvalues pairfirst pairgrep pairmap
-
-    shuffle uniq uniqint uniqnum uniqstr zip mesh
+    any all
   );
 
 =head1 DESCRIPTION
@@ -101,22 +85,16 @@ over using L<List::Util> directly.
 
 =item L<reduce|List::Util/reduce>
 
-=item L<reductions|List::Util/reductions>
-
 =item L<sum|List::Util/sum>
 
 =item L<sum0|List::Util/sum0>
 
-=item L<sample|List::Util/sample>
-
 =item L<shuffle|List::Util/shuffle>
 
 =item L<uniq|List::Util/uniq>
 
 =item L<uniqnum|List::Util/uniqnum>
 
-=item L<uniqint|List::Util/uniqint>
-
 =item L<uniqstr|List::Util/uniqstr>
 
 =item L<pairs|List::Util/pairs>
@@ -137,30 +115,6 @@ over using L<List::Util> directly.
 
 =item L<tail|List::Util/tail>
 
-=item L<zip|List::Util/zip>
-
-=item L<zip_longest|List::Util/zip>
-
-=item L<zip_shortest|List::Util/zip>
-
-=item L<mesh|List::Util/mesh>
-
-=item L<mesh_longest|List::Util/mesh>
-
-=item L<mesh_shortest|List::Util/mesh>
-
-=back
-
-=head1 CONFIGURATION VARIABLES
-
-=over 4
-
-=item L<$RAND|List::Util/$RAND>
-
-The variables C<$List::Util::RAND>, C<$List::Util::PP::RAND>, and
-C<$List::Util::MaybeXS::RAND> are all aliased to each other.  Any of them will
-impact both L<List::Util::PP> and L<List::Util> functions.
-
 =back
 
 =head1 DIFFERENCES FROM List::Util
@@ -174,8 +128,7 @@ with the interface.
 
 Inside a callback block (such as C<any { }>), C<@_> will be empty when using the
 pure perl implementation.  With the XS implementation, the outer C<@_> will be
-visible.  Under the perl debugger, the XS implementation will also not be able
-to see the outer C<@_>.
+visible.
 
 =back
 
